@@ -221,12 +221,14 @@ fn default_font_directories() -> Vec<PathBuf> {
     let mut directories = vec![
         PathBuf::from("/usr/share/fonts"),
         PathBuf::from("/usr/local/share/fonts"),
-        PathBuf::from("/var/run/host/usr/share/fonts"), // Flatpak specific
-        PathBuf::from("/var/run/host/usr/local/share/fonts"),
+        // Flatpak specific
+        PathBuf::from("/run/host/fonts"),
+        PathBuf::from("/run/host/local-fonts"),
+        PathBuf::from("/run/host/user-fonts"),
     ];
     if let Some(path) = dirs::home_dir() {
         directories.push(path.join(".fonts")); // ~/.fonts is deprecated
-        directories.push(path.join("local").join("share").join("fonts")); // Flatpak specific
+        directories.push(path.join(".local").join("share").join("fonts"));
     }
     if let Some(mut path) = dirs::data_dir() {
         path.push("fonts");
